==> openGion_core_5.9.16.0.zip: ge/db/sqlserver/sql/install/01_TABLE/GE20S.sql <==
/****************************************************************************/
/* GE20 ( ﾕｰｻﾞｰﾛｰﾙ設定値ﾃｰﾌﾞﾙ )                                             */
/*                                                                          */
/* Created : 2016/11/04 10:32:18                                            */
/****************************************************************************/
CREATE TABLE GE20 (
   SYSTEM_ID    varchar           (   10 )                  NOT NULL            /*  10 ｼｽﾃﾑID   */
 , USERID       varchar           (   10 )                  NOT NULL            /*  20 ﾕｰｻﾞｰID  */
 , ROLES        varchar           (  500 )                  NOT NULL            /*  30 ﾛｰﾙｽﾞ    */
 , PARAM_ID     varchar           (   50 )                  NOT NULL            /*  40 ﾊﾟﾗﾒｰﾀID */
 , PARAM        varchar           ( 4000 )                                      /*  50 設定値   */
 , KBSET        varchar           (    1 )      DEFAULT 0   NOT NULL            /*  60 設定区分 */
 , UNIQ         int IDENTITY(1,1)                                               /* 800 ﾕﾆｰｸｷｰ   */
 , FGJ          varchar           (    1 )      DEFAULT 1   NOT NULL            /* 810 状態ﾌﾗｸﾞ */
 , DYSET        varchar           (   14 )                                      /* 820 登録日時 */
 , PGSET        varchar           (   10 )                                      /* 830 作成PG   */
 , PGPSET       varchar           (   10 )                                      /* 840 作成親PG */
 , USRSET       varchar           (   10 )                                      /* 850 作成社員 */
 , DYUPD        varchar           (   14 )                                      /* 860 更新日時 */
 , PGUPD        varchar           (   10 )                                      /* 870 更新PG   */
 , PGPUPD       varchar           (   10 )                                      /* 880 更新親PG */
 , USRUPD       varchar           (   10 )                                      /* 890 更新者   */
);

==> openGion_core_5.9.19.0.zip: ge/db/sqlserver/sql/install/01_TABLE/GE20S.sql <==
/****************************************************************************/
/* GE20 ( ﾕｰｻﾞｰﾛｰﾙ設定値ﾃｰﾌﾞﾙ )                                             */
/*                                                                          */
/* Created : 2017/04/07 09:50:28                                            */
/****************************************************************************/
CREATE TABLE GE20 (
   SYSTEM_ID    varchar           (   10 )                  NOT NULL            /*  10 ｼｽﾃﾑID   */
 , USERID       varchar           (   10 )                  NOT NULL            /*  20 ﾕｰｻﾞｰID  */
 , ROLES        varchar           (  500 )                  NOT NULL            /*  30 ﾛｰﾙｽﾞ    */
 , PARAM_ID     varchar           (   50 )                  NOT NULL            /*  40 ﾊﾟﾗﾒｰﾀID */
 , PARAM        varchar           ( 4000 )                                      /*  50 設定値   */
 , KBSET        varchar           (    1 )      DEFAULT '0' NOT NULL            /*  60 設定区分 */
 , UNIQ         int IDENTITY(1,1)                                               /* 800 ﾕﾆｰｸｷｰ   */
 , FGJ          varchar           (    1 )      DEFAULT '1' NOT NULL            /* 810 状態ﾌﾗｸﾞ */
 , DYSET        varchar           (   14 )                                      /* 820 登録日時 */
 , PGSET        varchar           (   10 )                                      /* 830 作成PG   */
 , PGPSET       varchar           (   10 )                                      /* 840 作成親PG */
 , USRSET       varchar           (   10 )                                      /* 850 作成社員 */
 , DYUPD        varchar           (   14 )                                      /* 860 更新日時 */
 , PGUPD        varchar           (   10 )                                      /* 870 更新PG   */
 , PGPUPD       varchar           (   10 )                                      /* 880 更新親PG */
 , USRUPD       varchar           (   10 )                                      /* 890 更新者   */
);
